///////depth map
struct VS_OUT
{
	float4 hPosition	: POSITION;
	float4 Position		: TEXCOORD0;	
};

VS_OUT DepthVS(float4 position : POSITION,	
				uniform float4x4 worldViewProj,				
				uniform float4x4 viewProj,
				uniform float4x4 cameraMatrix)
{
  
  VS_OUT OUT;
 
  OUT.hPosition = mul(worldViewProj, position);
  OUT.Position = mul(viewProj, position);
  
  return OUT;
}

//for directional light
float4 DepthPS(VS_OUT IN ):COLOR
{
	float4 pos = (IN.Position / IN.Position.w);
	pos = (pos +1.0 ) / 2.0;
	return pos.z;	
}

///////////////Shadow

struct VS_OUT_SHADOW
{
	float4 hPosition	: POSITION;
	float4 Position		: TEXCOORD0;
	float4 lPosition	: TEXCOORD1;
};

VS_OUT_SHADOW depthShadowVS(float4 position : POSITION,	
							uniform float4x4 worldViewProj,
							uniform float4x4 lightViewProj)
{
  VS_OUT_SHADOW OUT;
  OUT.hPosition = mul(worldViewProj, position);
  OUT.lPosition = mul(lightViewProj, position);  
  OUT.Position = position;  
  return OUT;
}


float4 depthShadowPS(VS_OUT_SHADOW IN,
					uniform float4x4 lightViewProj,
					uniform sampler2D depthShadowMap : register(s0)
					):COLOR
{	
	float bias = 0.001;
	float4 light = float4(1,1,1,1);
	float4 shadow = float4(0.3,0.3,0.3,1);
	
	float4 pos = (IN.lPosition / IN.lPosition.w);
	pos = (pos +1.0 ) / 2.0;
	pos.y = 1.0 - pos.y;
	float4 storedDepth = tex2D(depthShadowMap, pos.xy);
	if(storedDepth.r + bias < pos.z)
		light = shadow;
	//return abs( pos.z - storedDepth.z );	
	return light;	
}

